@@ -118,7 +118,7 @@ def check_language(command_line_params, yaml_config):
     return 'language' in yaml_config or 'language' in command_line_params
 
 def version():
-    return '0.1.57'
+    return '0.1.58'
 
 def main():
     command_line_params, command_args = parse_command_line_params()
@@ -126,8 +126,11 @@ def main():
     succeed, yaml_config = Utils.read_config(build_dir)
     api_id, app_id = get_app_ids(command_args, yaml_config)
 
+    awsconfig = Utils.get_aws_config(app_id, api_id)
+    # count files and loc
+    files, lines_of_code = Utils.count_file_code(awsconfig, build_dir)
+
     if not check_language(command_line_params, yaml_config):
-        awsconfig = Utils.get_aws_config(app_id, api_id)
         command_line_params['language'] = Utils.detect_lang(awsconfig, build_dir, LANGUAGES)
 
     Utils.assert_docker_alive()
@@ -136,6 +139,8 @@ def main():
         'apiid': api_id, 
         'appid': app_id, 
         'buildDir': build_dir,
+        'files': files, 
+        'linesOfCode': lines_of_code, 
         'commandLine': command_line_params, 
         'yaml': yaml_config,
         'environment_variables': Utils.get_env_variables(command_args, yaml_config)
